from setuptools import setup, find_packages
import codecs
import os


with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# dependencies
dependencies = [
    'absl-py==1.1.0',
    'alabaster==0.7.12',
    'astunparse==1.6.3',
    'attrs==21.4.0',
    'Babel==2.10.1',
    'bleach==5.0.0',
    'build==0.8.0',
    'cachetools==5.2.0',
    'cbc==0.0.1',
    'certifi==2022.5.18.1',
    'cffi==1.15.0',
    'charset-normalizer==2.0.12',
    'commonmark==0.9.1',
    'cryptography==37.0.2',
    'cycler==0.11.0',
    'docutils==0.18.1',
    'flatbuffers==1.12',
    'fonttools==4.33.3',
    'gast==0.4.0',
    'google-auth==2.6.6',
    'google-auth-oauthlib==0.4.6',
    'google-pasta==0.2.0',
    'grpcio==1.46.3',
    'h5py==3.7.0',
    'idna==3.3',
    'imagesize==1.3.0',
    'importlib-metadata==4.11.4',
    'iniconfig==1.1.1',
    'jeepney==0.8.0',
    'Jinja2==3.1.2',
    'keras==2.9.0',
    'Keras-Preprocessing==1.1.2',
    'keyring==23.5.1',
    'kiwisolver==1.4.2',
    'libclang==14.0.1',
    'Markdown==3.3.7',
    'MarkupSafe==2.1.1',
    'matplotlib==3.5.2',
    'numpy==1.22.4',
    'oauthlib==3.2.0',
    'opencv-python==4.5.5.64',
    'opt-einsum==3.3.0',
    'packaging==21.3',
    'pep517==0.12.0',
    'Pillow==9.1.1',
    'pkginfo==1.8.2',
    'pluggy==1.0.0',
    'protobuf==3.19.4',
    'py==1.11.0',
    'pyasn1==0.4.8',
    'pyasn1-modules==0.2.8',
    'pycparser==2.21',
    'Pygments==2.12.0',
    'pyparsing==3.0.9',
    'python-dateutil==2.8.2',
    'pytz==2022.1',
    'readme-renderer==35.0',
    'requests==2.27.1',
    'requests-oauthlib==1.3.1',
    'requests-toolbelt==0.9.1',
    'rfc3986==2.0.0',
    'rich==12.4.4',
    'rsa==4.8',
    'scipy==1.8.1',
    'SecretStorage==3.3.2',
    'six==1.16.0',
    'snowballstemmer==2.2.0',
    'Sphinx==5.0.1',
    'sphinxcontrib-applehelp==1.0.2',
    'sphinxcontrib-devhelp==1.0.2',
    'sphinxcontrib-htmlhelp==2.0.0',
    'sphinxcontrib-jsmath==1.0.1',
    'sphinxcontrib-qthelp==1.0.3',
    'sphinxcontrib-serializinghtml==1.1.5',
    'tensorboard==2.9.0',
    'tensorboard-data-server==0.6.1',
    'tensorboard-plugin-wit==1.8.1',
    'tensorflow==2.9.1',
    'tensorflow-addons==0.17.0',
    'tensorflow-estimator==2.9.0',
    'tensorflow-io-gcs-filesystem==0.26.0',
    'termcolor==1.1.0',
    'tomli==2.0.1',
    'twine==4.0.1',
    'typeguard==2.13.3',
    'typing_extensions==4.2.0',
    'urllib3==1.26.9',
    'webencodings==0.5.1',
    'Werkzeug==2.1.2',
    'wrapt==1.14.1',
    'zipp==3.8.0'
]


# Setting up
setup(
    name='cbc',
    version='0.0.8',
    author='nemo256 (Amine Neggazi)',
    author_email='<neggazimedlamine@gmail.com>',
    description='Count Blood Cells',
    packages=find_packages(),
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='https://github.com/nemo256/cbc',
    install_requires=dependencies,
    keywords=['python', 'artificial intelligence', 'deep learning', 'blood cells', 'image segmentation', 'unet'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Operating System :: OS Independent',
    ],
    data_files=[
        ('share/cbc/weights', [
            'models/rbc.h5',
            'models/wbc.h5',
            'models/plt.h5'
        ]),
        ('share/cbc/images', [
            'test.jpg',
        ])
    ],
    scripts=['cbc']
)
